@@ -5,7 +5,7 @@ conLM.lm <- function(object, constraints = NULL, se = "standard",
                      debug = FALSE, ...) {
   
   # check class
-  if (!(class(object)[1] %in% c("lm"))) {
+  if (!(class(object)[1] == "lm")) {
     stop("Restriktor ERROR: object must be of class lm.")
   }
   # standard error methods
@@ -39,20 +39,25 @@ conLM.lm <- function(object, constraints = NULL, se = "standard",
   # model summary
   so <- summary(object)
   # unconstrained residual variance (weighted)
-  s2.unrestr <- so$sigma^2
+  s2 <- so$sigma^2
   # weigths
   weights <- weights(object)
   # unconstrained estimates
   b.unrestr <- coef(object)
+  b.unrestr[abs(b.unrestr) < ifelse(is.null(control$tol), 
+                                sqrt(.Machine$double.eps), 
+                                control$tol)] <- 0L
   # ML unconstrained MSE
-  #invW <- kronecker(solve(s2.unrestr), t(X) %*% X)
-  Sigma <- vcov(object)#solve(invW)
+  Sigma <- vcov(object)
   # number of parameters
   p <- length(coef(object))
   # sample size
   n <- dim(X)[1]
-  # compute (weighted) log-likelihood
-  ll.unrestr <- con_loglik_lm(object)
+  # compute log-likelihood
+  residuals <- object$residuals
+  object.restr <- list(residuals = residuals, weights = weights)
+  ll.unrestr <- con_loglik_lm(object.restr)
+  
   
   if (debug) {
     print(list(loglik.unc = ll.unrestr))
@@ -88,22 +93,29 @@ conLM.lm <- function(object, constraints = NULL, se = "standard",
     meq  <- 0L
   } 
   
+  # if only new parameters are defined and no constraints
+  if (length(Amat) == 0L) {
+    Amat <- rbind(rep(0L, p))
+    bvec <- rep(0L, nrow(Amat))
+    meq  <- 0L
+  }
+  
   # compute the reduced row-echelon form of the constraints matrix
   rAmat <- GaussianElimination(t(Amat))
   if (mix.weights == "pmvnorm") {
     if (rAmat$rank < nrow(Amat) && rAmat$rank != 0L) {
       stop(paste("Restriktor ERROR: The constraint matrix must have full row-rank", 
-                 "\n  (choose e.g. rows", paste(rAmat$pivot, collapse = " "), ",or try to set mix.weights = \"boot\")"))
+                 "\n  (choose e.g. rows", paste(rAmat$pivot, collapse = " "),")."))
     }
   } 
   else if (rAmat$rank < nrow(Amat) && 
              !(se %in% c("none", "boot.model.based", "boot.standard")) && 
              rAmat$rank != 0L) {
-      se <- "none"
-      warning(paste("Restriktor Warning: No standard errors could be computed. 
-                      The constraint matrix must have full row-rank ( choose e.g. rows", 
-                    paste(rAmat$pivot, collapse = " "), "), 
-                      Try se = \"boot.model.based\" or \"boot.standard\"."))  
+    se <- "none"
+    warning(paste("Restriktor Warning: No standard errors could be computed. 
+                    The constraint matrix must have full row-rank ( choose e.g. rows", 
+                  paste(rAmat$pivot, collapse = " "), "), 
+                    Try se = \"boot.model.based\" or \"boot.standard\"."))  
   }
   
   timing$constraints <- (proc.time()[3] - start.time)
@@ -114,6 +126,10 @@ conLM.lm <- function(object, constraints = NULL, se = "standard",
          "\n       columns constraints-matrix must be identical")
   }
 
+  if (!(nrow(Amat) == length(bvec))) {
+    stop("nrow(Amat) != length(bvec)")
+  }
+  
   is.augmented <- TRUE
   # compute chi-square-bar weights
   if (mix.weights != "none") {
@@ -145,7 +161,7 @@ conLM.lm <- function(object, constraints = NULL, se = "standard",
   } else {
     wt.bar <- NA
   }
-  attr(wt.bar, "wt.bar.method") <- mix.weights
+  attr(wt.bar, "method") <- mix.weights
   
   if (debug) {
     print(list(mix.weights = wt.bar))
@@ -157,7 +173,6 @@ conLM.lm <- function(object, constraints = NULL, se = "standard",
   # check if the constraints are not in line with the data, else skip optimization
   if (all(Amat %*% c(b.unrestr) - bvec >= 0 * bvec) & meq == 0) {
     b.restr  <- b.unrestr
-    s2.restr <- s2.unrestr
     
     OUT <- list(CON         = CON,
                 call        = mc,
@@ -165,14 +180,13 @@ conLM.lm <- function(object, constraints = NULL, se = "standard",
                 parTable    = parTable,
                 b.unrestr   = b.unrestr,
                 b.restr     = b.unrestr,
-                residuals   = object$residuals, # unweighted residuals
+                residuals   = residuals, # unweighted residuals
                 fitted      = object$fitted,
                 weights     = weights,
                 df.residual = object$df.residual,
                 R2.org      = so$r.squared, 
                 R2.reduced  = so$r.squared,
-                s2.unrestr  = s2.unrestr, 
-                s2.restr    = s2.unrestr, 
+                s2          = s2, 
                 loglik      = ll.unrestr, 
                 Sigma       = Sigma,
                 constraints = Amat, 
@@ -184,20 +198,21 @@ conLM.lm <- function(object, constraints = NULL, se = "standard",
                 control     = control)  
   } else {
     # compute constrained estimates using quadprog
-    out.QP <- con_solver_lm(X         = X, 
-                            y         = y, 
-                            b.unrestr = b.unrestr, 
-                            w         = weights, 
-                            Amat      = Amat,
-                            bvec      = bvec, 
-                            meq       = meq, 
-                            absval    = ifelse(is.null(control$absval), 
-                                            sqrt(.Machine$double.eps), 
-                                            control$absval),
-                            maxit     = ifelse(is.null(control$maxit), 1e04, 
-                                            control$maxit))
-    
-    b.restr <- matrix(out.QP$solution, ncol = ncol(y))
+    out.solver <- con_solver_lm(X         = X, 
+                                y         = y, 
+                                #b.unrestr = b.unrestr, 
+                                w         = weights, 
+                                Amat      = Amat,
+                                bvec      = bvec, 
+                                meq       = meq, 
+                                absval    = ifelse(is.null(control$absval), 
+                                                sqrt(.Machine$double.eps), 
+                                                control$absval),
+                                maxit     = ifelse(is.null(control$maxit), 1e04, 
+                                                control$maxit))
+    out.QP <- out.solver$qp
+    b.restr <- out.QP$solution
+      names(b.restr) <- names(b.unrestr)
     b.restr[abs(b.restr) < ifelse(is.null(control$tol), 
                                   sqrt(.Machine$double.eps), 
                                   control$tol)] <- 0L
@@ -207,8 +222,6 @@ conLM.lm <- function(object, constraints = NULL, se = "standard",
     
     # lm
     if (ncol(y) == 1L) {
-      b.restr <- as.vector(b.restr)
-        names(b.restr) <- names(b.unrestr)
       fitted <- X %*% b.restr
       residuals <- y - fitted
       
@@ -239,12 +252,12 @@ conLM.lm <- function(object, constraints = NULL, se = "standard",
       df.residual <- n - (p - qr(Amat[0:meq,])$rank)
       # compute weighted residuals
       if (is.null(weights)) {
-        s2.restr <- sum(residuals^2) / df.residual  
+        s2 <- sum(residuals^2) / df.residual  
       } else {
-        s2.restr <- sum(weights * residuals^2) / df.residual
+        s2 <- sum(weights * residuals^2) / df.residual
       }
-    } else { #mlm <FIXME>
-      stop("mlm not implemented (yet)")
+    } else { 
+      stop("mlm not supported. Switch to conMLM.")
     }
 
     OUT <- list(CON         = CON,
@@ -259,8 +272,7 @@ conLM.lm <- function(object, constraints = NULL, se = "standard",
                 df.residual = object$df.residual,
                 R2.org      = so$r.squared, 
                 R2.reduced  = R2.reduced,
-                s2.unrestr  = s2.unrestr, 
-                s2.restr    = s2.restr, 
+                s2          = s2,
                 loglik      = ll.restr, 
                 Sigma       = Sigma,
                 constraints = Amat, 
@@ -276,12 +288,12 @@ conLM.lm <- function(object, constraints = NULL, se = "standard",
   OUT$model.org <- object
   # type standard error
   OUT$se <- se
-  OUT$information <- 1/s2.restr * crossprod(X)
+  OUT$information <- 1/s2 * crossprod(X)
   # compute standard errors based on the augmented inverted information matrix or
   # based on the standard bootstrap or model.based bootstrap
   if (se != "none") {
     if (!(se %in% c("boot.model.based","boot.standard"))) {
-      information.inv <- con_augmented_information(information  = OUT$information,
+      information.inv <- con_augmented_information(information  = OUT$information, 
                                                    is.augmented = is.augmented,
                                                    X            = X, 
                                                    b.unrestr    = b.unrestr, 
@@ -338,11 +350,7 @@ conLM.lm <- function(object, constraints = NULL, se = "standard",
   
   OUT$timing$total <- (proc.time()[3] - start.time0)
   
-  if (ncol(y) == 1L) {
-    class(OUT) <- c("restriktor", "conLM")
-  } else if (ncol(y) > 1L) {
-    class(OUT) <- c("restriktor", "conMLM")
-  }
+  class(OUT) <- c("restriktor", "conLM")
     
   OUT
 }
\ No newline at end of file
